@@ -1,6 +1,6 @@
 package Module::Build::Tiny;
 {
-  $Module::Build::Tiny::VERSION = '0.028';
+  $Module::Build::Tiny::VERSION = '0.029';
 }
 use strict;
 use warnings;
@@ -15,7 +15,7 @@ use ExtUtils::InstallPaths 0.002;
 use File::Basename qw/basename dirname/;
 use File::Find ();
 use File::Path qw/mkpath rmtree/;
-use File::Spec::Functions qw/catfile catdir rel2abs abs2rel splitdir/;
+use File::Spec::Functions qw/catfile catdir rel2abs abs2rel splitdir curdir/;
 use Getopt::Long qw/GetOptions/;
 use JSON::PP 2 qw/encode_json decode_json/;
 
@@ -63,10 +63,11 @@ sub process_xs {
 	my $version = $options->{meta}->version;
 	require ExtUtils::CBuilder;
 	my $builder = ExtUtils::CBuilder->new(config => $options->{config}->values_set);
-	my $ob_file = $builder->compile(source => $c_file, defines => { VERSION => qq/"$version"/, XS_VERSION => qq/"$version"/ });
+	my $ob_file = $builder->compile(source => $c_file, defines => { VERSION => qq/"$version"/, XS_VERSION => qq/"$version"/ }, include_dirs => curdir);
 
 	mkpath($archdir, $options->{verbose}, oct '755') unless -d $archdir;
-	return $builder->link(objects => $ob_file, lib_file => catfile($archdir, "$file_base." . $options->{config}->get('dlext')), module_name => join '::', @dirnames, $file_base);
+	my $lib_file = catfile($archdir, "$file_base." . $options->{config}->get('dlext'));
+	return $builder->link(objects => $ob_file, lib_file => $lib_file, module_name => join '::', @dirnames, $file_base);
 }
 
 sub find {
@@ -98,8 +99,8 @@ my %actions = (
 	test => sub {
 		my %opt = @_;
 		die "Must run `./Build build` first\n" if not -d 'blib';
-		require TAP::Harness;
-		my $tester = TAP::Harness->new({ verbosity => $opt{verbose}, lib => [ map { rel2abs(catdir(qw/blib/, $_)) } qw/arch lib/ ], color => -t STDOUT });
+		require TAP::Harness::Env;
+		my $tester = TAP::Harness::Env->create({ verbosity => $opt{verbose}, lib => [ map { rel2abs(catdir(qw/blib/, $_)) } qw/arch lib/ ], color => -t STDOUT });
 		$tester->runtests(sort +find(qr/\.t$/, 't'))->has_errors and exit 1;
 	},
 	install => sub {
@@ -155,7 +156,7 @@ Module::Build::Tiny - A tiny replacement for Module::Build
 
 =head1 VERSION
 
-version 0.028
+version 0.029
 
 =head1 SYNOPSIS
 
